@@ -24,11 +24,26 @@
 class HttpResponseHeader
 {
 public:
-    HttpResponseHeader(const QString &str){parse(str);}
-    int statusCode(){return _statCode;}
-    QString reasonPhrase(){return _reasonPhr;}
-    QString value(const QString &key)const {return values[key.toLower()];}
-    bool hasKey(const QString &key)const {return values.contains(key.toLower());}
+    HttpResponseHeader(const QString &str)
+    {
+        parse(str);
+    }
+    int statusCode()
+    {
+        return _statCode;
+    }
+    QString reasonPhrase()
+    {
+        return _reasonPhr;
+    }
+    QString value(const QString &key)const
+    {
+        return values[key.toLower()];
+    }
+    bool hasKey(const QString &key)const
+    {
+        return values.contains(key.toLower());
+    }
 private:
     bool parse(const QString &);
     bool parseLine(const QString &line, int number);
