@@ -29,73 +29,71 @@
 namespace bt
 {
 
-    AccessManager::AccessManager()
-    {
-        banned = new BadPeersList();
-        addBlockList(banned);
-    }
+AccessManager::AccessManager()
+{
+    banned = new BadPeersList();
+    addBlockList(banned);
+}
 
 
-    AccessManager::~AccessManager()
-    {
-        qDeleteAll(blocklists);
-    }
+AccessManager::~AccessManager()
+{
+    qDeleteAll(blocklists);
+}
 
-    AccessManager& AccessManager::instance()
-    {
-        static AccessManager inst;
-        return inst;
-    }
+AccessManager& AccessManager::instance()
+{
+    static AccessManager inst;
+    return inst;
+}
 
-    void AccessManager::addBlockList(BlockListInterface* bl)
-    {
-        blocklists.append(bl);
-    }
+void AccessManager::addBlockList(BlockListInterface* bl)
+{
+    blocklists.append(bl);
+}
 
-    void AccessManager::removeBlockList(BlockListInterface* bl)
-    {
-        blocklists.removeAll(bl);
-    }
+void AccessManager::removeBlockList(BlockListInterface* bl)
+{
+    blocklists.removeAll(bl);
+}
 
-    bool AccessManager::allowed(const net::Address& addr) const
-    {
-        // Don't connect to the custom IP sent to the tracker, this should be our own'
-        if(isOurOwnAddress(addr))
-            return false;
-
-        foreach(const BlockListInterface* bl, blocklists)
-        {
-            if(bl->blocked(addr))
-                return false;
-        }
-        return true;
-    }
-
-    void AccessManager::banPeer(const QString& addr)
-    {
-        banned->addBadPeer(addr);
-    }
-    
-    void AccessManager::addExternalIP(const QString& addr)
-    {
-        external_addresses.append(addr);
-    }
-    
-    bool AccessManager::isOurOwnAddress(const net::Address& addr) const
-    {
-        Uint16 port = bt::Server::getPort();
-        if(!Tracker::getCustomIP().isEmpty() && net::Address(Tracker::getCustomIP(), port) == addr)
-            return true;
-            
-           
-        foreach(const QString& ip, external_addresses)
-        {
-            net::Address address(ip, port);
-            if(address == addr)
-                return true;
-        }
-        
+bool AccessManager::allowed(const net::Address& addr) const
+{
+    // Don't connect to the custom IP sent to the tracker, this should be our own'
+    if (isOurOwnAddress(addr))
         return false;
+
+    for (const BlockListInterface* bl : qAsConst(blocklists)) {
+        if (bl->blocked(addr))
+            return false;
     }
+    return true;
+}
+
+void AccessManager::banPeer(const QString& addr)
+{
+    banned->addBadPeer(addr);
+}
+
+void AccessManager::addExternalIP(const QString& addr)
+{
+    external_addresses.append(addr);
+}
+
+bool AccessManager::isOurOwnAddress(const net::Address& addr) const
+{
+    Uint16 port = bt::Server::getPort();
+    if (!Tracker::getCustomIP().isEmpty() && net::Address(Tracker::getCustomIP(), port) == addr)
+        return true;
+
+
+    for (const QString& ip : qAsConst(external_addresses)) {
+        net::Address address(ip, port);
+        if (address == addr)
+            return true;
+    }
+
+    return false;
+}
 
 }
