@@ -29,69 +29,68 @@ class KJob;
 
 namespace KIO
 {
-	class MetaData;
+class MetaData;
 }
 
 namespace bt
 {
-	
 
-	/**
-	 * @author Joris Guisson
-	 * @brief Communicates with the tracker
-	 *
-	 * This class uses the HTTP protocol to communicate with the tracker.
-	 */
-	class KTORRENT_EXPORT HTTPTracker : public Tracker
-	{
-		Q_OBJECT
-	public:
-		HTTPTracker(const QUrl &url,TrackerDataSource* tds,const PeerID & id,int tier);
-		virtual ~HTTPTracker();
-		
-		virtual void start();
-		virtual void stop(WaitJob* wjob = 0);
-		virtual void completed();
-		virtual Uint32 failureCount() const {return failures;}
-		virtual void scrape();
-		
-		static void setProxy(const QString & proxy,const bt::Uint16 proxy_port);
-		static void setProxyEnabled(bool on);
-		static void setUseQHttp(bool on);
-		
-	private Q_SLOTS:
-		void onKIOAnnounceResult(KJob* j);
-#ifdef HAVE_HTTPANNOUNEJOB
-		void onQHttpAnnounceResult(KJob* j);
-#endif
-		void onScrapeResult(KJob* j);
-		void emitInvalidURLFailure();
-		void onTimeout();
-		virtual void manualUpdate();
 
-	private:
-		void doRequest(WaitJob* wjob = 0);
-		bool updateData(const QByteArray & data);
-		void setupMetaData(KIO::MetaData & md);
- 		void doAnnounceQueue();
- 		void doAnnounce(const QUrl &u);
-		void onAnnounceResult(const QUrl &url,const QByteArray & data,KJob* j);
+/**
+ * @author Joris Guisson
+ * @brief Communicates with the tracker
+ *
+ * This class uses the HTTP protocol to communicate with the tracker.
+ */
+class KTORRENT_EXPORT HTTPTracker : public Tracker
+{
+    Q_OBJECT
+public:
+    HTTPTracker(const QUrl &url, TrackerDataSource* tds, const PeerID & id, int tier);
+    ~HTTPTracker() override;
 
-	private:
-		KJob* active_job;
-		QList<QUrl> announce_queue;
-		QString event;
-		QTimer timer;
-		QString error;
-		Uint32 failures;
-		bool supports_partial_seed_extension;
-		
-		
-		static bool proxy_on;
-		static QString proxy;
-		static Uint16 proxy_port;
-		static bool use_qhttp;
-	};
+    void start() override;
+    void stop(WaitJob* wjob = 0) override;
+    void completed() override;
+    Uint32 failureCount() const override
+    {
+        return failures;
+    }
+    void scrape() override;
+
+    static void setProxy(const QString & proxy, const bt::Uint16 proxy_port);
+    static void setProxyEnabled(bool on);
+    [[deprecated]] static void setUseQHttp(bool on);
+
+private Q_SLOTS:
+    void onKIOAnnounceResult(KJob* j);
+    void onScrapeResult(KJob* j);
+    void emitInvalidURLFailure();
+    void onTimeout();
+    void manualUpdate() override;
+
+private:
+    void doRequest(WaitJob* wjob = 0);
+    bool updateData(const QByteArray & data);
+    void setupMetaData(KIO::MetaData & md);
+    void doAnnounceQueue();
+    void doAnnounce(const QUrl &u);
+    void onAnnounceResult(const QUrl &url, const QByteArray & data, KJob* j);
+
+private:
+    KJob* active_job;
+    QList<QUrl> announce_queue;
+    QString event;
+    QTimer timer;
+    QString error;
+    Uint32 failures;
+    bool supports_partial_seed_extension;
+
+
+    static bool proxy_on;
+    static QString proxy;
+    static Uint16 proxy_port;
+};
 
 }
 
