@@ -28,66 +28,60 @@ using namespace utp;
 
 class ConnectTest : public QEventLoop
 {
-	Q_OBJECT
 public:
-	
-public Q_SLOTS:
-	void accepted()
-	{
-		accepted_conn = srv.acceptedConnection().toStrongRef();
-		exit();
-	}
-	
-	void endEventLoop()
-	{
-		exit();
-	}
-	
-	void startConnect()
-	{
-		net::Address addr("127.0.0.1",port);
-		srv.connectTo(addr);
-		QTimer::singleShot(5000,this,SLOT(endEventLoop())); // use a 5 second timeout
-	}
-	
-private Q_SLOTS:
-	void initTestCase()
-	{
-		bt::InitLog("connecttest.log");
-		
-		port = 50000;
-		while (port < 60000)
-		{
-			if (!srv.changePort(port))
-				port++;
-			else
-				break;
-		}
-		
-		srv.setCreateSockets(false);
-		srv.start();
-		QVERIFY(port < 60000);
-	}
-	
-	void cleanupTestCase()
-	{
-		srv.stop();
-	}
-	
-	void testConnect()
-	{
-		connect(&srv,SIGNAL(accepted()),this,SLOT(accepted()),Qt::QueuedConnection);
-		QTimer::singleShot(0,this,SLOT(startConnect()));
-		exec();
-		QVERIFY(accepted_conn != 0);
-	}
-	
+    void accepted()
+    {
+        accepted_conn = srv.acceptedConnection().toStrongRef();
+        exit();
+    }
+
+    void endEventLoop()
+    {
+        exit();
+    }
+
+    void startConnect()
+    {
+        net::Address addr("127.0.0.1", port);
+        srv.connectTo(addr);
+        QTimer::singleShot(5000, this, &ConnectTest::endEventLoop); // use a 5 second timeout
+    }
+
 private:
-	utp::UTPServer srv;
-	int port;
-	utp::Connection::Ptr accepted_conn;
+    void initTestCase()
+    {
+        bt::InitLog("connecttest.log");
+
+        port = 50000;
+        while (port < 60000) {
+            if (!srv.changePort(port))
+                port++;
+            else
+                break;
+        }
+
+        srv.setCreateSockets(false);
+        srv.start();
+        QVERIFY(port < 60000);
+    }
+
+    void cleanupTestCase()
+    {
+        srv.stop();
+    }
+
+    void testConnect()
+    {
+        connect(&srv, &utp::UTPServer::accepted, this, &ConnectTest::accepted, Qt::QueuedConnection);
+        QTimer::singleShot(0, this, &ConnectTest::startConnect);
+        exec();
+        QVERIFY(accepted_conn != nullptr);
+    }
+
+private:
+    utp::UTPServer srv;
+    int port;
+    utp::Connection::Ptr accepted_conn;
 };
 
 QTEST_MAIN(ConnectTest)
-
-#include "connecttest.moc"
